#[non_exhaustive]pub enum DiagnosticKind {
OverfullBox,
MissingCharacter,
FontSubstitution,
HostBox,
}Expand description
Kind of a Diagnostic.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OverfullBox
A box is wider or taller than its set size.
MissingCharacter
A font has no glyph for a character, which is dropped.
FontSubstitution
LaTeX substituted a font for one it could not find.
HostBox
A host box was missing or rejected and nothing was drawn for it.