#[non_exhaustive]pub enum FormatError {
NotAFormat,
Version {
found: u8,
},
Corrupt,
Image {
message: String,
},
}Expand description
Why bytes are not a usable format.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotAFormat
The bytes do not start with the packaged format header.
Version
The container was written by a version of this crate with another layout.
Corrupt
The payload does not inflate or its parts do not add up.
Image
The format image was dumped by another engine build or on a big endian target, or fails validation.