#[non_exhaustive]pub enum ResourceKind {
TexInput,
Package,
Class,
FontDefinition,
PackageSupport,
Font,
Encoding,
Map,
Config,
FormatImage,
Asset,
}Expand description
Kind of file a request asks for, which picks the suffixes the engine tries and the search path.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TexInput
TeX input file requested by \input.
Package
LaTeX package.
Class
LaTeX document class.
FontDefinition
Font definition file such as .fd.
PackageSupport
Package support file such as .clo, .def, .ldf or .cfg.
Font
Font metric file or font program.
Encoding
Font encoding vector.
Map
Font map.
Config
Engine configuration file.
FormatImage
Precompiled format image.
Asset
Other file owned by a package.
Implementations