pub struct FormatSnapshot {
pub macros: Vec<MacroDefinition>,
pub packages: Vec<FormatPackage>,
pub resources: Vec<FormatResource>,
pub opaque_engine_state: Vec<u8>,
pub registers: RegisterSnapshot,
}Expand description
Structured initialized format state that can be cloned into sessions.
Fields
macros: Vec<MacroDefinition>Macro definitions or macro state records preloaded into the format.
packages: Vec<FormatPackage>Packages incorporated during format initialization.
resources: Vec<FormatResource>Resources captured during format initialization.
opaque_engine_state: Vec<u8>Opaque bytes for generated engine state during bootstrap.
registers: RegisterSnapshotRegister values captured at format initialization time.