pub struct BakedGeneratedFormat { /* private fields */ }Expand description
A static baked format containing a zero copy image view and its native font table.
Implementations
Sourceimpl BakedGeneratedFormat
impl BakedGeneratedFormat
Sourcepub fn from_static_bytes(bytes: &'static [u8]) -> Option<Self>
pub fn from_static_bytes(bytes: &'static [u8]) -> Option<Self>
Validates and borrows a baked file without inflating or copying the image.
Sourcepub fn cache(&self) -> &GeneratedFormatCache
pub fn cache(&self) -> &GeneratedFormatCache
Returns the zero copy generated format cache.
Sourcepub fn font_table(&self) -> Vec<(PortableFontHandle, String, i32)>
pub fn font_table(&self) -> Vec<(PortableFontHandle, String, i32)>
Decodes the native font table for restoration on a new engine instance.