pub type EmptyGeneratedFontPlatform = EmptyFontPlatform;Expand description
Empty font platform for use when native font loading is disabled.
Aliased Type
pub struct EmptyGeneratedFontPlatform;pub type EmptyGeneratedFontPlatform = EmptyFontPlatform;Empty font platform for use when native font loading is disabled.
pub struct EmptyGeneratedFontPlatform;