ConfigurablePlatform

Struct ConfigurablePlatform 

pub struct ConfigurablePlatform<D> { /* private fields */ }
Platform implementation composed from a diagnostic sink, host limits, and a clock.

Implementations

Source

impl<D> ConfigurablePlatform<D>

pub fn new(diagnostics: D, limits: HostLimits) -> Self

Creates a platform with the given diagnostic sink and limits.

pub fn with_diagnostics(diagnostics: D) -> Self

Creates a platform with the given diagnostic sink and default limits.

pub fn with_clock(self, clock: HostClock) -> Self

Returns a copy of this platform with the clock set to clock.

pub fn diagnostic_sink(&self) -> &D

Returns a reference to the underlying diagnostic sink.

pub fn host_limits(&self) -> HostLimits

Returns the configured host limits.

pub fn host_clock(&self) -> HostClock

Returns the configured host clock.