pub struct HostBoxRequest {
pub token: i32,
pub style: HostBoxStyle,
pub font_size: i32,
}Expand description
Parameters for a host box request passed to the platform.
Fields
token: i32Opaque host owned token identifier scanned from \hostbox{...}.
style: HostBoxStyleMath style context at the placement site.
font_size: i32Font size context in scaled points at the placement site.