pub struct LinebreakRequest<'a> {
pub font: i32,
pub locale: i32,
pub text: &'a [u16],
}Expand description
Parameters for a host driven line break request passed to the platform.
Fields
font: i32Generated engine font identifier active for the text.
locale: i32Generated engine locale identifier active for the text.
text: &'a [u16]Text slice owned by generated engine memory for this call.