pub struct NoopPlatform { /* private fields */ }Expand description
Minimal deterministic platform for tests, embedded use, and early bootstrap.
Implementations
Sourceimpl NoopPlatform
impl NoopPlatform
Sourcepub fn with_limits(limits: HostLimits) -> Self
pub fn with_limits(limits: HostLimits) -> Self
Creates a noop platform with the given host limits.
Sourcepub fn with_clock(clock: HostClock) -> Self
pub fn with_clock(clock: HostClock) -> Self
Creates a noop platform with the given clock value.