#[non_exhaustive]pub enum EnginePatch {
Etex,
Xetex,
}Expand description
An individual capability patch that can be layered onto a TexCore.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Etex
eTeX register and primitive extensions.
Xetex
XeTeX Unicode and font extensions, which also imply eTeX behavior.