pub struct EnginePatches { /* private fields */ }Expand description
Bit-set recording which engine patches are active on a core.
Implementations
Sourceimpl EnginePatches
impl EnginePatches
Sourcepub const fn with(self, patch: EnginePatch) -> Self
pub const fn with(self, patch: EnginePatch) -> Self
Returns a new EnginePatches with the given patch added.
Sourcepub const fn from_extension_policy(policy: ExtensionPolicy) -> Self
pub const fn from_extension_policy(policy: ExtensionPolicy) -> Self
Derives an EnginePatches value from an ExtensionPolicy.
Sourcepub const fn contains(&self, patch: EnginePatch) -> bool
pub const fn contains(&self, patch: EnginePatch) -> bool
Returns true if the given patch is present in this set.