#[non_exhaustive]pub enum ResourceError {
NotFound {
name: String,
kind: ResourceKind,
},
Invalid {
name: String,
message: String,
},
Denied {
name: String,
message: String,
},
}Expand description
Error returned when a resource request cannot be fulfilled.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFound
The requested resource does not exist in the configured universe.
Fields

kind: ResourceKindKind of resource that was requested.
Invalid
The resource exists but is not valid for the requested purpose.
Fields
Denied
The resolver policy denied the request.