ResourceFontSystem

Struct ResourceFontSystem 

pub struct ResourceFontSystem<R> { /* private fields */ }
Loads font bytes through a ResourceProvider, shaping is unsupported.

Implementations

Source

impl<R> ResourceFontSystem<R>

pub fn new(resources: R) -> Self

Creates a font system backed by the given resource provider.

Examples found in repository?
examples/pack_native_format.rs (line 57)
55    fn new(texmf: Arc<TexmfResources>) -> Self {
56        Self {
57            inner: RustybuzzFontSystem::new(ResourceFontSystem::new(TexmfFontProvider { texmf })),
58        }
59    }
pub fn resources(&self) -> &R

Returns a reference to the underlying resource provider.

pub fn into_resources(self) -> R

Unwraps and returns the underlying resource provider.

pub fn cached_font_count(&self) -> usize

Number of font resources cached by resolver facing name.