#[non_exhaustive]pub enum FormatPreloadError {
InputRejected {
name: String,
},
Aborted {
name: String,
status: Option<i32>,
},
Resource {
name: String,
resource: String,
},
Transcript {
name: String,
message: String,
},
}Expand description
Error encountered while preloading format resources into the generated engine.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InputRejected
The generated engine rejected the given input file.
Aborted
The generated engine aborted before completing initialization.
Fields
Resource
A required resource could not be loaded during preload.
Fields
Transcript
The engine transcript contained a TeX error during preload.