Engine

Struct Engine 

pub struct Engine<P, R, H, F = NoFontSystem> { /* private fields */ }
Engine initialized from a format image with associated resource, platform, and font boundaries.

Implementations

Source

impl<P, R, H> Engine<P, R, H>

pub fn new( profile: P, format: FormatImage, resources: R, platform: H, ) -> Result<Self, BuildError>

Constructs an engine without a font system.

Source

impl<P, R, H, F> Engine<P, R, H, F>

pub fn new_with_fonts( profile: P, format: FormatImage, resources: R, platform: H, fonts: F, ) -> Result<Self, BuildError>

Constructs an engine with an explicit font system.

pub fn builder(profile: P) -> EngineBuilder<P, (), (), NoFontSystem>

Returns a staged builder for this engine profile.

pub fn new_session(&self) -> EngineSession<'_, P, R, H, F>

Create a session, the session holds a clone of the mutable format state.

pub fn profile(&self) -> &P

Returns the engine profile.

pub fn semantics(&self) -> &EngineSemantics

Computed semantics derived from the engine profile.

pub fn format(&self) -> &FormatImage

Returns the loaded format image.

pub fn generated_format(&self) -> &GeneratedFormatCache

Preloaded generated engine format image.

pub fn resources(&self) -> &R

Returns the resource provider.

pub fn platform(&self) -> &H

Returns the platform adapter.

pub fn fonts(&self) -> &F

Returns the font system.

pub fn primitives(&self) -> &PrimitiveRegistry

Primitive dispatch table for this engine profile.