#[non_exhaustive]pub struct HostBoxRun {
pub font: FontKey,
pub size: Length,
pub glyphs: Vec<HostBoxGlyph>,
}Expand description
Glyphs of one face inside a host box, the fragment carries the key so the host can draw them.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.font: FontKeyKey of the host’s face.
size: LengthSize the glyphs are drawn at.
glyphs: Vec<HostBoxGlyph>Glyphs in drawing order.
Implementations
Sourceimpl HostBoxRun
impl HostBoxRun