#[non_exhaustive]pub struct ResourceRequest {
pub name: String,
pub kind: ResourceKind,
pub package: Option<String>,
}Expand description
A request for a named resource of a given kind.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringFile name as TeX asked for it, without the owning package.
kind: ResourceKindKind of file TeX asked for.
package: Option<String>Owning package of an ResourceKind::Asset request.
Implementations
Sourceimpl ResourceRequest
impl ResourceRequest
Sourcepub fn new(name: impl Into<String>, kind: ResourceKind) -> Self
pub fn new(name: impl Into<String>, kind: ResourceKind) -> Self
A request for name of the given kind.
Sourcepub fn asset(package: impl Into<String>, name: impl Into<String>) -> Self
pub fn asset(package: impl Into<String>, name: impl Into<String>) -> Self
A request for an asset file owned by package.
Sourcepub fn canonical_name(&self) -> String
pub fn canonical_name(&self) -> String
The name providers key resources by, package/name for an asset and the file name otherwise.