Portable TeX engine library for formats, sessions, IR emission, and host platform traits.
Re-exports
pub use emit::EmitNode;pub use emit::IrEmitter;pub use format::FormatImage;pub use format::FormatInitError;pub use format::FormatInitializer;pub use format::FormatPackage;pub use format::FormatResource;pub use format::FormatResourceKind;pub use format::FormatSnapshot;pub use format::FormatState;pub use format::MacroDefinition;pub use format::RegisterSnapshot;pub use format::SessionState;pub use generated::generated_node_to_fragment;pub use generated::EmptyGeneratedFontPlatform;pub use generated::EmptyGeneratedPlatform;pub use generated::GeneratedClock;pub use generated::GeneratedFontHandle;pub use generated::GeneratedFontMetrics;pub use generated::GeneratedFontPlatform;pub use generated::GeneratedFontSystemAdapter;pub use generated::GeneratedFormatCache;pub use generated::GeneratedLayoutCapture;pub use generated::GeneratedLinebreakRequest;pub use generated::GeneratedNodeHandle;pub use generated::GeneratedNodeKind;pub use generated::GeneratedNodeSnapshot;pub use generated::GeneratedNodeSourceSpan;pub use generated::GeneratedPlatform;pub use generated::GeneratedPlatformAdapter;pub use generated::GeneratedResourceProvider;pub use generated::GeneratedResourceRequestRecord;pub use generated::GeneratedSourceSpan;pub use platform::CollectingDiagnosticSink;pub use platform::ConfigurablePlatform;pub use platform::Diagnostic;pub use platform::DiagnosticSeverity;pub use platform::DiagnosticSink;pub use platform::HostClock;pub use platform::HostLimits;pub use platform::LimitError;pub use platform::LinebreakRequest;pub use platform::NoopDiagnosticSink;pub use platform::NoopPlatform;pub use platform::Platform;pub use primitive::PrimitiveEntry;pub use primitive::PrimitiveRegistry;pub use primitive::PrimitiveRegistryError;pub use profile::CatcodeDefaults;pub use profile::EngineKind;pub use profile::EnginePatch;pub use profile::EnginePatches;pub use profile::EngineProfile;pub use profile::EngineSemantics;pub use profile::EtexProfile;pub use profile::ExtensionPolicy;pub use profile::FontSemantics;pub use profile::MathcodeDefaults;pub use profile::PrimitiveKind;pub use profile::PrimitiveOpcode;pub use profile::PrimitiveSpec;pub use profile::ProfileId;pub use profile::RegisterDefaults;pub use profile::TexCore;pub use profile::TexProfile;pub use profile::XetexProfile;pub use resource::FileSystemResourceProvider;pub use texmf::TexmfResources;pub use resource::InMemoryResourceProvider;pub use resource::OverlayResourceProvider;pub use resource::ResolverResourceProvider;pub use resource::Resource;pub use resource::ResourceBundle;pub use resource::ResourceError;pub use resource::ResourceKind;pub use resource::ResourceProvider;pub use resource::ResourceRequest as ProviderResourceRequest;pub use resource::ResourceRequestSource;pub use resource_font::ResourceFontSystem;pub use session::BuildError;pub use session::Engine;pub use session::EngineBuilder;pub use session::EngineError;pub use session::EngineSession;pub use session::FormatPreloadError;pub use session::FragmentInput;pub use mathtex_font as font;pub use mathtex_portable_engine_generated as portable_engine;
Modules
- emit
- IR emitter that translates TeX shipout calls to layout nodes.
- format
- Format image serialization, deserialization, and snapshot types.
- generated
- Code generated from the WEB source: engine tables, dispatch, and node types.
- platform
- Host platform trait and bundled implementations for diagnostics, limits, and clocks.
- primitive
- Registry mapping primitive names to dispatch opcodes.
- profile
- Engine profile definitions: catcodes, primitives, semantics, and patches.
- resource
- Resource provider trait and bundled implementations for fonts, packages, and inputs.
- resource_
font - Font adapter that loads bytes through a resource provider.
- session
- Engine session construction, execution, and fragment rendering.
- texmf
- Native filesystem resource provider backed by a TeX live tree and
ls-Rindex. Native filesystemResourceProviderover a TeXLive tree usingls-Rand texmf.cnf priority.