pub struct ConfigurablePlatform<D> { /* private fields */ }Expand description
Platform implementation composed from a diagnostic sink, host limits, and a clock.
Implementations
Sourceimpl<D> ConfigurablePlatform<D>
impl<D> ConfigurablePlatform<D>
Sourcepub fn new(diagnostics: D, limits: HostLimits) -> Self
pub fn new(diagnostics: D, limits: HostLimits) -> Self
Creates a platform with the given diagnostic sink and limits.
Sourcepub fn with_diagnostics(diagnostics: D) -> Self
pub fn with_diagnostics(diagnostics: D) -> Self
Creates a platform with the given diagnostic sink and default limits.
Sourcepub fn with_clock(self, clock: HostClock) -> Self
pub fn with_clock(self, clock: HostClock) -> Self
Returns a copy of this platform with the clock set to clock.
Sourcepub fn diagnostic_sink(&self) -> &D
pub fn diagnostic_sink(&self) -> &D
Returns a reference to the underlying diagnostic sink.
Sourcepub fn host_limits(&self) -> HostLimits
pub fn host_limits(&self) -> HostLimits
Returns the configured host limits.
Sourcepub fn host_clock(&self) -> HostClock
pub fn host_clock(&self) -> HostClock
Returns the configured host clock.