pub struct Engine<P, R, H, F = NoFontSystem> { /* private fields */ }Expand description
Engine initialized from a format image with associated resource, platform, and font boundaries.
Implementations
Sourceimpl<P, R, H> Engine<P, R, H>
impl<P, R, H> Engine<P, R, H>
Sourcepub fn new(
profile: P,
format: FormatImage,
resources: R,
platform: H,
) -> Result<Self, BuildError>
pub fn new( profile: P, format: FormatImage, resources: R, platform: H, ) -> Result<Self, BuildError>
Constructs an engine without a font system.
Sourceimpl<P, R, H, F> Engine<P, R, H, F>
impl<P, R, H, F> Engine<P, R, H, F>
Sourcepub fn new_with_fonts(
profile: P,
format: FormatImage,
resources: R,
platform: H,
fonts: F,
) -> Result<Self, BuildError>
pub fn new_with_fonts( profile: P, format: FormatImage, resources: R, platform: H, fonts: F, ) -> Result<Self, BuildError>
Constructs an engine with an explicit font system.
Sourcepub fn builder(profile: P) -> EngineBuilder<P, (), (), NoFontSystem>
pub fn builder(profile: P) -> EngineBuilder<P, (), (), NoFontSystem>
Returns a staged builder for this engine profile.
Sourcepub fn new_session(&self) -> EngineSession<'_, P, R, H, F>
pub fn new_session(&self) -> EngineSession<'_, P, R, H, F>
Create a session, the session holds a clone of the mutable format state.
Sourcepub fn semantics(&self) -> &EngineSemantics
pub fn semantics(&self) -> &EngineSemantics
Computed semantics derived from the engine profile.
Sourcepub fn format(&self) -> &FormatImage
pub fn format(&self) -> &FormatImage
Returns the loaded format image.
Sourcepub fn generated_format(&self) -> &GeneratedFormatCache
pub fn generated_format(&self) -> &GeneratedFormatCache
Preloaded generated engine format image.
Sourcepub fn primitives(&self) -> &PrimitiveRegistry
pub fn primitives(&self) -> &PrimitiveRegistry
Primitive dispatch table for this engine profile.