EngineBuilder

Struct EngineBuilder 

pub struct EngineBuilder<P, R, H, F = NoFontSystem> { /* private fields */ }
Staged builder for constructing an engine with typed resource, platform, and font parameters.

Implementations

Source

impl<P> EngineBuilder<P, (), (), NoFontSystem>

pub fn new(profile: P) -> Self

Creates a new builder for an engine with the given profile.

Source

impl<P, R, H, F> EngineBuilder<P, R, H, F>

pub fn format(self, format: FormatImage) -> Self

Sets the format image for the engine being built.

pub fn resources<NextR>(self, resources: NextR) -> EngineBuilder<P, NextR, H, F>

Sets the resource provider for the engine being built.

pub fn platform<NextH>(self, platform: NextH) -> EngineBuilder<P, R, NextH, F>

Sets the platform adapter for the engine being built.

pub fn fonts<NextF>(self, fonts: NextF) -> EngineBuilder<P, R, H, NextF>

Sets the font system for the engine being built.

Source

impl<P, R, H, F> EngineBuilder<P, R, H, F>

pub fn build(self) -> Result<Engine<P, R, H, F>, BuildError>

Validates the builder state and constructs an engine.