pub struct EngineBuilder<P, R, H, F = NoFontSystem> { /* private fields */ }Expand description
Staged builder for constructing an engine with typed resource, platform, and font parameters.
Implementations
Sourceimpl<P> EngineBuilder<P, (), (), NoFontSystem>
impl<P> EngineBuilder<P, (), (), NoFontSystem>
Sourceimpl<P, R, H, F> EngineBuilder<P, R, H, F>
impl<P, R, H, F> EngineBuilder<P, R, H, F>
Sourcepub fn format(self, format: FormatImage) -> Self
pub fn format(self, format: FormatImage) -> Self
Sets the format image for the engine being built.
Sourcepub fn resources<NextR>(self, resources: NextR) -> EngineBuilder<P, NextR, H, F>
pub fn resources<NextR>(self, resources: NextR) -> EngineBuilder<P, NextR, H, F>
Sets the resource provider for the engine being built.
Sourcepub fn platform<NextH>(self, platform: NextH) -> EngineBuilder<P, R, NextH, F>
pub fn platform<NextH>(self, platform: NextH) -> EngineBuilder<P, R, NextH, F>
Sets the platform adapter for the engine being built.
Sourcepub fn fonts<NextF>(self, fonts: NextF) -> EngineBuilder<P, R, H, NextF>
pub fn fonts<NextF>(self, fonts: NextF) -> EngineBuilder<P, R, H, NextF>
Sets the font system for the engine being built.
Sourceimpl<P, R, H, F> EngineBuilder<P, R, H, F>
impl<P, R, H, F> EngineBuilder<P, R, H, F>
Sourcepub fn build(self) -> Result<Engine<P, R, H, F>, BuildError>
pub fn build(self) -> Result<Engine<P, R, H, F>, BuildError>
Validates the builder state and constructs an engine.